@@ -1,5 +1,5 @@
 #
-# Copyright 2008-2013 Universidad Complutense de Madrid
+# Copyright 2008-2014 Universidad Complutense de Madrid
 # 
 # This file is part of Numina
 # 
@@ -24,7 +24,8 @@ from .pipeline import Instrument, Pipeline, InstrumentConfiguration
 from .pipeline import ObservingMode
 from .pipeline import import_object
 from .pipeline import drp_load, init_drp_system
-from .requirements import RequirementParser, DataProductRequirement
+from .requirements import DataProductRequirement
+from .load import RequirementParser
 from .requirements import Parameter, Requirement
 from .products import DataProduct, FrameDataProduct
 from numina.exceptions import RecipeError
@@ -32,3 +33,4 @@ from .recipereqs import RecipeRequirements, define_requirements
 from .reciperesult import RecipeResult, Product, Optional
 from .reciperesult import define_result
 from .oresult import obsres_from_dict
+from .qc import QC
